@@ -4,9 +4,8 @@ use strict;
 use warnings;
 
 use Carp;
-use Errno qw( EWOULDBLOCK );
 use IO::Pipe;
-use POSIX ();
+use Errno qw( EWOULDBLOCK );
 
 
 sub new {
@@ -20,7 +19,7 @@ sub new {
 }
 
 sub child {
-  my ( $self, $std_h, $fileno ) = @_;
+  my ( $self, $std_h ) = @_;
 
   my $handle;
 
@@ -35,8 +34,8 @@ sub child {
       or confess "$self->{name}: open: /dev/null: $!\n";
   }
 
-  POSIX::dup2( $handle->fileno, $fileno )
-    or confess "$self->{name}: dup2: $!\n"
+  $std_h->fdopen( $handle, 'r' )
+    or confess "$self->{name}: fdopen: $!\n"
       if $std_h != $handle;
 }
 
@@ -149,8 +148,8 @@ is used when writing to a child process's C<STDIN>.
 Creates a new C<Proc::Hevy::Writer> object.  C<$name>
 is a symbolic name for the writer.  C<$buffer> is the source
 mechanism to used for data written to the child process.  It
-can either be a simple scalar, an C<ARRAY> reference, a C<CODE>
-reference or a C<GLOB> reference.
+can either be a simple scalar, an ARRAY reference, a CODE
+reference or a GLOB reference.
 
 =item B<child( $handle )>
 
