@@ -6,7 +6,7 @@ use warnings;
 use Carp;
 use Proc::Hevy;
 
-our $VERSION = '0.09_02';
+our $VERSION = '0.01';
 
 
 sub new {
@@ -17,18 +17,15 @@ sub new {
   my %args = @args;
 
   confess 'command: Required parameter'
-    unless defined $args{command};
+    unless exists $args{command};
 
   bless {
-    command  => $args{command},
-    stdin    => $args{stdin},
-    stdout   => [ ],
-    stderr   => [ ],
-    status   => undef,
-    parent   => $args{parent},
-    child    => $args{child},
-    priority => $args{priority},
-  }, $class
+    command => $args{command},
+    stdin   => $args{stdin},
+    stdout  => [ ],
+    stderr  => [ ],
+    status  => undef,
+  }
 }
 
 sub exec {
@@ -40,13 +37,10 @@ sub run {
   my ( $self ) = @_;
 
   my $status = Proc::Hevy->exec(
-    command  => $self->{command},
-    stdin    => $self->{stdin},
-    stdout   => $self->{stdout},
-    stderr   => $self->{stderr},
-    parent   => $self->{parent},
-    child    => $self->{child},
-    priority => $self->{priority},
+    command => $self->{command},
+    stdin   => $self->{stdin},
+    stdout  => $self->{stdout},
+    stderr  => $self->{stderr},
   );
 
   $self->{status} = $status >> 8;
@@ -117,7 +111,7 @@ Proc::Lite - A lightweight module for running processes synchronously
   }
 
   {
-    my $proc = Proc::Lite->exec( qw( ls -l ), @ARGV );
+    my $proc = Proc::Lite->exec(qw( ls -l ), @ARGV );
     if( $proc->success ) {
       print "success\n";
       print " => $_\n"
@@ -136,28 +130,6 @@ Proc::Lite - A lightweight module for running processes synchronously
     my $proc = Proc::Lite->exec( \&echo, @ARGV );
   }
 
-  {
-    my $proc = Proc::Lite->new(
-      priority => 10,
-
-      command => sub {
-        print "In child process ($$): command\n";
-      },
-
-      parent => sub {
-        my ( $pid ) = @_;
-
-        print "In parent process ($$): child=$pid\n";
-      },
-
-      child => sub {
-        my ( $ppid ) = @_;
-
-        print "In child process ($$): parent=$ppid\n";
-      },
-    )->run;
-  }
-
 =head1 DESCRIPTION
 
 C<Proc::Lite> is a lightweight, easy-to-use wrapper around
@@ -186,8 +158,8 @@ running the command.  C<%args> may contain the following options:
 
 Specifies the command to run.  The first form may expand shell
 meta-characters while the second form will not.  Review the
-documentation for C<exec()> for more information.  The third
-form will run the given C<CODE> reference in the child process
+documentation for C<exec> for more information.  The third
+form will run the given code reference in the child process
 and the fourth form does the same, but also passes in C<@args>
 as arguments to the subroutine.  This option is required.
 
@@ -203,29 +175,12 @@ Specifies data that may be sent to the child process's C<STDIN>.
 The first form simply sends the given string of bytes to the
 child process.  The second form will write individual array
 elements to the child process.  The third form will run the
-given C<CODE> reference and write the return value to the child.
+given code reference and write the return value to the child.
 A value of C<undef> signals that no more input should be sent
 to the child process.  The fourth form simply re-opens the
 child's C<STDIN> handle to the given filehandle allowing a
 pass-through effect.  If this option is not given, the
-child's C<STDIN> will be reopened to C<'/dev/null'>.
-
-=item C<parent =E<gt> \&code>
-
-If specified, the given C<CODE> reference is called in the
-parent process after the C<fork()> is performed.  The child
-process's PID is passed in as a single argument.
-
-=item C<child =E<gt> \&code>
-
-If specified, the given C<CODE> reference is called in the
-child process after the C<fork()> is performed.  The parent
-process's PID is passed in as a single argument.
-
-=item C<priority =E<gt> $delta>
-
-If specified, adjusts the child process's priority according
-to the value specified.
+child's STDIN will be reopened to C<'/dev/null'>.
 
 =back
 
@@ -249,7 +204,7 @@ the ways C<new()>'s C<command> argument may be specified.
 
 Runs the command specified in C<new()>.  It returns the
 C<Proc::Lite> object so that it can be called in
-conjunction with C<new()> (C<Proc::Lite-E<gt>new( ... )-E<gt>run>).
+conjunction with new (C<Proc::Lite-E<gt>new( ... )-E<gt>run>).
 
 =item B<status>
 
@@ -259,7 +214,7 @@ Returns the exit status from the process.
 
 Returns the C<STDOUT> output from the child process.  In
 list context, the output is returned as a list.  In scalar
-context, an C<ARRAY> reference is returned.
+context, an array reference is returned.
 
 =item B<stderr>
 
